/* midi - MIDI file library and Simple Software Synthesizer
 * Copyright (C) 2004 by Patrick Reynolds <reynolds@cs.duke.edu>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <stdio.h>
#include <glib.h>
#include "midifile.h"

static void mididump(const char *filename);

int main(int argc, char **argv) {
	int i;
	if (argc < 2) {
		fprintf(stderr, "Usage:\n  %s file [file [file [...]]]\n", argv[0]);
		return -1;
	}
	for (i=1; i<argc; i++)
		mididump(argv[i]);

	return 0;
}

static void mididump(const char *filename) {
	MIDIFile *mf;
	int i;
	FILE *fp = fopen(filename, "r");
	if (!fp) { perror(filename); return; }

	mf = read_midi_file(fp);
	printf("fmt=%d numtracks=%d division=%d\n",
		mf->header->format, mf->header->numtracks, mf->header->division);
	printf("  #events:");
	for (i=0; i<mf->tracks->len; i++) {
		Track *t = g_ptr_array_index(mf->tracks, i);
		printf(" %d", t->events->len);
	}
	printf("\n");

	merge_tracks(mf);

	printf("fmt=%d numtracks=%d division=%d\n",
		mf->header->format, mf->header->numtracks, mf->header->division);
	printf("  #events:");
	for (i=0; i<mf->tracks->len; i++) {
		Track *t = g_ptr_array_index(mf->tracks, i);
		printf(" %d", t->events->len);
	}
	printf("\n");

	free_midi_file(mf);
	fclose(fp);
}
